@@ -466,10 +466,9 @@ class CameraConfigInputSettings(TypedDict):
     role: CameraRole
     useForSnapshot: bool
     hotMode: bool
-    urls: NotRequired[list[str]]
 
 
-class CameraConfig(TypedDict):
+class BaseCameraConfig(TypedDict):
     name: str
     nativeId: Optional[str]
     isCloud: Optional[bool]
@@ -477,8 +476,12 @@ class CameraConfig(TypedDict):
     info: Optional[CameraInformation]
 
 
-class PartialCameraConfig(CameraConfig, total=False):
-    pass
+class CameraConfig(BaseCameraConfig):
+    sources: list[CameraConfigInputSettings]
+
+
+class PartialCameraConfig(BaseCameraConfig, total=False):
+    sources: NotRequired[list[CameraConfigInputSettings]]
 
 
 class RTSPUrlOptions(TypedDict, total=False):
