@@ -1,5 +1,5 @@
 import asyncio
-import logging
+import contextlib
 from collections.abc import AsyncIterator, Awaitable, Sequence
 from typing import (
     Any,
@@ -29,20 +29,9 @@ class DisposableProtocol(Protocol):
 
 
 class HybridObservable(Observable[T], Generic[T]):
-    """
-    A hybrid observable that supports both synchronous and asynchronous operations.
-    Provides compatibility between ReactiveX and asyncio.
-    """
-
     _observable: Observable[T]
 
     def __init__(self, observable: Observable[T]):
-        """
-        Initialize the hybrid observable with a regular observable.
-
-        Args:
-            observable: The underlying ReactiveX observable
-        """
         super().__init__(observable._subscribe)
         self._observable = observable
 
@@ -103,7 +92,6 @@ class HybridObservable(Observable[T], Generic[T]):
             nonlocal error_occurred
             error_occurred = True
             if not future.done():
-                logging.error(f"Error in observable: {error}")
                 future.set_exception(error)
 
         def on_completed() -> None:
@@ -156,7 +144,7 @@ class HybridObservable(Observable[T], Generic[T]):
         """
         return HybridObservable(self._observable.pipe(*operators))
 
-    async def asubscribe(
+    def asubscribe(
         self,
         on_next: Union[Callable[[T], Awaitable[Any]], None] = None,
         on_error: Union[Callable[[Exception], Awaitable[Any]], None] = None,
@@ -165,43 +153,67 @@ class HybridObservable(Observable[T], Generic[T]):
         """
         Subscribe asynchronously to the observable sequence.
         """
-        future: asyncio.Future[None] = asyncio.Future()
+        error_future: asyncio.Future[Exception] = asyncio.Future()
+        next_task: Optional[asyncio.Task[Any]] = None
+        error_task: Optional[asyncio.Task[Any]] = None
+        completed_task: Optional[asyncio.Task[Any]] = None
+
+        is_completed = False
 
         async def async_on_next(value: T) -> None:
             if on_next:
-                await on_next(value)
-
-        async def async_on_error(error: Exception) -> None:
-            if on_error:
-                await on_error(error)
-            if not future.done():
-                future.set_exception(error)
+                try:
+                    await on_next(value)
+                except Exception as e:
+                    if not is_completed:
+                        error_future.set_result(e)
 
         async def async_on_completed() -> None:
+            nonlocal is_completed
+            nonlocal next_task
+
+            is_completed = True
+
+            if next_task and not next_task.done():
+                next_task.cancel()
+                next_task = None
+
             if on_completed:
-                await on_completed()
-            if not future.done():
-                future.set_result(None)
+                try:
+                    await on_completed()
+                except Exception as e:
+                    error_future.set_result(e)
+
+        async def async_on_error() -> None:
+            error = await error_future
+            if on_error:
+                disposable.dispose()
+                with contextlib.suppress(Exception):
+                    await on_error(error)
 
         def next_fn(x: T) -> None:
-            asyncio.create_task(async_on_next(x))
-
-        def error_fn(e: Exception) -> None:
-            asyncio.create_task(async_on_error(e))
+            nonlocal next_task
+            next_task = asyncio.create_task(async_on_next(x), name="on_next")
 
         def completed_fn() -> None:
-            asyncio.create_task(async_on_completed())
+            nonlocal completed_task
+            completed_task = asyncio.create_task(async_on_completed(), name="on_completed")
 
-        disposable = self.subscribe(next_fn, error_fn, completed_fn)
+        if on_error:
+            error_task = asyncio.create_task(async_on_error(), name="on_error")
+
+        disposable = self.subscribe(next_fn, None, completed_fn)
 
         def cancel_subscription() -> None:
+            for task in (next_task, error_task, completed_task):
+                if task:
+                    task.cancel()
+
             disposable.dispose()
-            if not future.done():
-                future.cancel()
 
         return RxDisposable(cancel_subscription)
 
-    async def asubscribe_with_backpressure(
+    def asubscribe_with_backpressure(
         self, on_next: Optional[Callable[[T], Awaitable[Any]]] = None, max_queue_size: int = 100
     ) -> RxDisposable:
         """
@@ -287,10 +299,7 @@ class HybridObservable(Observable[T], Generic[T]):
         Asynchronous cleanup of resources.
         Handles both synchronous and asynchronous disposal.
         """
-        # Führe synchrone dispose aus
         self.dispose()
-
-        # Warte auf ausstehende Tasks oder Futures
         pending_tasks = [task for task in asyncio.all_tasks() if task is not asyncio.current_task()]
         if pending_tasks:
             await asyncio.gather(*pending_tasks, return_exceptions=True)
